==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/ess/v20201111/models/CreateFlowRemindsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ess.v20201111.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CreateFlowRemindsResponse extends AbstractModel{

    /**
    * 签署连接过期时间字符串：年月日-时分秒
    */
    @SerializedName("RemindFlowRecords")
    @Expose
    private RemindFlowRecords [] RemindFlowRecords;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 签署连接过期时间字符串：年月日-时分秒 
     * @return RemindFlowRecords 签署连接过期时间字符串：年月日-时分秒
     */
    public RemindFlowRecords [] getRemindFlowRecords() {
        return this.RemindFlowRecords;
    }

    /**
     * Set 签署连接过期时间字符串：年月日-时分秒
     * @param RemindFlowRecords 签署连接过期时间字符串：年月日-时分秒
     */
    public void setRemindFlowRecords(RemindFlowRecords [] RemindFlowRecords) {
        this.RemindFlowRecords = RemindFlowRecords;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public CreateFlowRemindsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public CreateFlowRemindsResponse(CreateFlowRemindsResponse source) {
        if (source.RemindFlowRecords != null) {
            this.RemindFlowRecords = new RemindFlowRecords[source.RemindFlowRecords.length];
            for (int i = 0; i < source.RemindFlowRecords.length; i++) {
                this.RemindFlowRecords[i] = new RemindFlowRecords(source.RemindFlowRecords[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "RemindFlowRecords.", this.RemindFlowRecords);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.830-sources.jar: com/tencentcloudapi/ess/v20201111/models/CreateFlowRemindsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ess.v20201111.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CreateFlowRemindsResponse extends AbstractModel{

    /**
    * 催办合同详情列表
    */
    @SerializedName("RemindFlowRecords")
    @Expose
    private RemindFlowRecords [] RemindFlowRecords;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 催办合同详情列表 
     * @return RemindFlowRecords 催办合同详情列表
     */
    public RemindFlowRecords [] getRemindFlowRecords() {
        return this.RemindFlowRecords;
    }

    /**
     * Set 催办合同详情列表
     * @param RemindFlowRecords 催办合同详情列表
     */
    public void setRemindFlowRecords(RemindFlowRecords [] RemindFlowRecords) {
        this.RemindFlowRecords = RemindFlowRecords;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public CreateFlowRemindsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public CreateFlowRemindsResponse(CreateFlowRemindsResponse source) {
        if (source.RemindFlowRecords != null) {
            this.RemindFlowRecords = new RemindFlowRecords[source.RemindFlowRecords.length];
            for (int i = 0; i < source.RemindFlowRecords.length; i++) {
                this.RemindFlowRecords[i] = new RemindFlowRecords(source.RemindFlowRecords[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "RemindFlowRecords.", this.RemindFlowRecords);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
